"""
ISO 3166-1 standard representation.

References:
  - https://en.wikipedia.org/wiki/ISO_3166-1
  - https://www.iso.org/glossary-for-iso-3166.html
  - https://www.iso.org/obp/ui/en/#iso:std:iso:3166:-1:ed-4:v1:en
  - https://www.iso.org/obp/ui/#search
"""

from iso_standards.base import EntityCollection
from iso_standards.iso3166.types import Iso3166_1 as Entity


class Iso3166_1(EntityCollection):
    __slots__ = ()

    entities = {
        "AD": Entity("Andorra", "AD", "AND", "020", "Andorra", ""),
        "AE": Entity("United Arab Emirates", "AE", "ARE", "784", "United Arab Emirates (the)", ""),
        "AF": Entity("Afghanistan", "AF", "AFG", "004", "Afghanistan", ""),
        "AG": Entity("Antigua and Barbuda", "AG", "ATG", "028", "Antigua and Barbuda", ""),
        "AI": Entity("Anguilla", "AI", "AIA", "660", "Anguilla", "GB"),
        "AL": Entity("Albania", "AL", "ALB", "008", "Albania", ""),
        "AM": Entity("Armenia", "AM", "ARM", "051", "Armenia", ""),
        "AO": Entity("Angola", "AO", "AGO", "024", "Angola", ""),
        "AQ": Entity("Antarctica", "AQ", "ATA", "010", "Antarctica", ""),
        "AR": Entity("Argentina", "AR", "ARG", "032", "Argentina", ""),
        "AS": Entity("American Samoa", "AS", "ASM", "016", "American Samoa", "US"),
        "AT": Entity("Austria", "AT", "AUT", "040", "Austria", ""),
        "AU": Entity("Australia", "AU", "AUS", "036", "Australia", ""),
        "AW": Entity("Aruba", "AW", "ABW", "533", "Aruba", "NL"),
        "AX": Entity("Åland Islands", "AX", "ALA", "248", "Åland Islands", "FI"),
        "AZ": Entity("Azerbaijan", "AZ", "AZE", "031", "Azerbaijan", ""),
        "BA": Entity("Bosnia and Herzegovina", "BA", "BIH", "070", "Bosnia and Herzegovina", ""),
        "BB": Entity("Barbados", "BB", "BRB", "052", "Barbados", ""),
        "BD": Entity("Bangladesh", "BD", "BGD", "050", "Bangladesh", ""),
        "BE": Entity("Belgium", "BE", "BEL", "056", "Belgium", ""),
        "BF": Entity("Burkina Faso", "BF", "BFA", "854", "Burkina Faso", ""),
        "BG": Entity("Bulgaria", "BG", "BGR", "100", "Bulgaria", ""),
        "BH": Entity("Bahrain", "BH", "BHR", "048", "Bahrain", ""),
        "BI": Entity("Burundi", "BI", "BDI", "108", "Burundi", ""),
        "BJ": Entity("Benin", "BJ", "BEN", "204", "Benin", ""),
        "BL": Entity("Saint Barthélemy", "BL", "BLM", "652", "Saint Barthélemy", "FR"),
        "BM": Entity("Bermuda", "BM", "BMU", "060", "Bermuda", "GB"),
        "BN": Entity("Brunei Darussalam", "BN", "BRN", "096", "Brunei Darussalam", ""),
        "BO": Entity("Bolivia", "BO", "BOL", "068", "Bolivia (Plurinational State of)", ""),
        "BQ": Entity("Bonaire", "BQ", "BES", "535", "Bonaire, Sint Eustatius and Saba", "NL"),
        "BR": Entity("Brazil", "BR", "BRA", "076", "Brazil", ""),
        "BS": Entity("Bahamas", "BS", "BHS", "044", "Bahamas (the)", ""),
        "BT": Entity("Bhutan", "BT", "BTN", "064", "Bhutan", ""),
        "BV": Entity("Bouvet Island", "BV", "BVT", "074", "Bouvet Island", "NO"),
        "BW": Entity("Botswana", "BW", "BWA", "072", "Botswana", ""),
        "BY": Entity("Belarus", "BY", "BLR", "112", "Belarus", ""),
        "BZ": Entity("Belize", "BZ", "BLZ", "084", "Belize", ""),
        "CA": Entity("Canada", "CA", "CAN", "124", "Canada", ""),
        "CC": Entity("Cocos", "CC", "CCK", "166", "Cocos (Keeling) Islands (the)", "AU"),
        "CD": Entity("Congo", "CD", "COD", "180", "Congo (the Democratic Republic of the)", ""),
        "CF": Entity(
            "Central African Republic", "CF", "CAF", "140", "Central African Republic (the)", ""
        ),
        "CG": Entity("Congo", "CG", "COG", "178", "Congo (the)", ""),
        "CH": Entity("Switzerland", "CH", "CHE", "756", "Switzerland", ""),
        "CI": Entity("Côte d'Ivoire", "CI", "CIV", "384", "Côte d'Ivoire", ""),
        "CK": Entity("Cook Islands", "CK", "COK", "184", "Cook Islands (the)", "NZ"),
        "CL": Entity("Chile", "CL", "CHL", "152", "Chile", ""),
        "CM": Entity("Cameroon", "CM", "CMR", "120", "Cameroon", ""),
        "CN": Entity("China", "CN", "CHN", "156", "China", ""),
        "CO": Entity("Colombia", "CO", "COL", "170", "Colombia", ""),
        "CR": Entity("Costa Rica", "CR", "CRI", "188", "Costa Rica", ""),
        "CU": Entity("Cuba", "CU", "CUB", "192", "Cuba", ""),
        "CV": Entity("Cabo Verde", "CV", "CPV", "132", "Cabo Verde", ""),
        "CW": Entity("Curaçao", "CW", "CUW", "531", "Curaçao", "NL"),
        "CX": Entity("Christmas Island", "CX", "CXR", "162", "Christmas Island", "AU"),
        "CY": Entity("Cyprus", "CY", "CYP", "196", "Cyprus", ""),
        "CZ": Entity("Czechia", "CZ", "CZE", "203", "Czechia", ""),
        "DE": Entity("Germany", "DE", "DEU", "276", "Germany", ""),
        "DJ": Entity("Djibouti", "DJ", "DJI", "262", "Djibouti", ""),
        "DK": Entity("Denmark", "DK", "DNK", "208", "Denmark", ""),
        "DM": Entity("Dominica", "DM", "DMA", "212", "Dominica", ""),
        "DO": Entity("Dominican Republic", "DO", "DOM", "214", "Dominican Republic (the)", ""),
        "DZ": Entity("Algeria", "DZ", "DZA", "012", "Algeria", ""),
        "EC": Entity("Ecuador", "EC", "ECU", "218", "Ecuador", ""),
        "EE": Entity("Estonia", "EE", "EST", "233", "Estonia", ""),
        "EG": Entity("Egypt", "EG", "EGY", "818", "Egypt", ""),
        "EH": Entity("Western Sahara", "EH", "ESH", "732", "Western Sahara", "MA"),
        "ER": Entity("Eritrea", "ER", "ERI", "232", "Eritrea", ""),
        "ES": Entity("Spain", "ES", "ESP", "724", "Spain", ""),
        "ET": Entity("Ethiopia", "ET", "ETH", "231", "Ethiopia", ""),
        "FI": Entity("Finland", "FI", "FIN", "246", "Finland", ""),
        "FJ": Entity("Fiji", "FJ", "FJI", "242", "Fiji", ""),
        "FK": Entity("Falkland Islands", "FK", "FLK", "238", "Falkland Islands (the)", "GB"),
        "FM": Entity("Micronesia", "FM", "FSM", "583", "Micronesia (Federated States of)", ""),
        "FO": Entity("Faroe Islands", "FO", "FRO", "234", "Faroe Islands (the)", "DK"),
        "FR": Entity("France", "FR", "FRA", "250", "France", ""),
        "GA": Entity("Gabon", "GA", "GAB", "266", "Gabon", ""),
        "GB": Entity(
            "United Kingdom",
            "GB",
            "GBR",
            "826",
            "United Kingdom of Great Britain and Northern Ireland (the)",
            "",
        ),
        "GD": Entity("Grenada", "GD", "GRD", "308", "Grenada", ""),
        "GE": Entity("Georgia", "GE", "GEO", "268", "Georgia", ""),
        "GF": Entity("French Guiana", "GF", "GUF", "254", "French Guiana", "FR"),
        "GG": Entity("Guernsey", "GG", "GGY", "831", "Guernsey", "GB"),
        "GH": Entity("Ghana", "GH", "GHA", "288", "Ghana", ""),
        "GI": Entity("Gibraltar", "GI", "GIB", "292", "Gibraltar", "GB"),
        "GL": Entity("Greenland", "GL", "GRL", "304", "Greenland", "DK"),
        "GM": Entity("Gambia", "GM", "GMB", "270", "Gambia (the)", ""),
        "GN": Entity("Guinea", "GN", "GIN", "324", "Guinea", ""),
        "GP": Entity("Guadeloupe", "GP", "GLP", "312", "Guadeloupe", "FR"),
        "GQ": Entity("Equatorial Guinea", "GQ", "GNQ", "226", "Equatorial Guinea", ""),
        "GR": Entity("Greece", "GR", "GRC", "300", "Greece", ""),
        "GS": Entity(
            "South Georgia and the South Sandwich Islands",
            "GS",
            "SGS",
            "239",
            "South Georgia and the South Sandwich Islands",
            "GB",
        ),
        "GT": Entity("Guatemala", "GT", "GTM", "320", "Guatemala", ""),
        "GU": Entity("Guam", "GU", "GUM", "316", "Guam", "US"),
        "GW": Entity("Guinea-Bissau", "GW", "GNB", "624", "Guinea-Bissau", ""),
        "GY": Entity("Guyana", "GY", "GUY", "328", "Guyana", ""),
        "HK": Entity("Hong Kong", "HK", "HKG", "344", "Hong Kong", "CN"),
        "HM": Entity(
            "Heard Island and McDonald Islands",
            "HM",
            "HMD",
            "334",
            "Heard Island and McDonald Islands",
            "AU",
        ),
        "HN": Entity("Honduras", "HN", "HND", "340", "Honduras", ""),
        "HR": Entity("Croatia", "HR", "HRV", "191", "Croatia", ""),
        "HT": Entity("Haiti", "HT", "HTI", "332", "Haiti", ""),
        "HU": Entity("Hungary", "HU", "HUN", "348", "Hungary", ""),
        "ID": Entity("Indonesia", "ID", "IDN", "360", "Indonesia", ""),
        "IE": Entity("Ireland", "IE", "IRL", "372", "Ireland", ""),
        "IL": Entity("Israel", "IL", "ISR", "376", "Israel", ""),
        "IM": Entity("Isle of Man", "IM", "IMN", "833", "Isle of Man", "GB"),
        "IN": Entity("India", "IN", "IND", "356", "India", ""),
        "IO": Entity(
            "British Indian Ocean Territory",
            "IO",
            "IOT",
            "086",
            "British Indian Ocean Territory (the)",
            "GB",
        ),
        "IQ": Entity("Iraq", "IQ", "IRQ", "368", "Iraq", ""),
        "IR": Entity("Iran", "IR", "IRN", "364", "Iran (Islamic Republic of)", ""),
        "IS": Entity("Iceland", "IS", "ISL", "352", "Iceland", ""),
        "IT": Entity("Italy", "IT", "ITA", "380", "Italy", ""),
        "JE": Entity("Jersey", "JE", "JEY", "832", "Jersey", "GB"),
        "JM": Entity("Jamaica", "JM", "JAM", "388", "Jamaica", ""),
        "JO": Entity("Jordan", "JO", "JOR", "400", "Jordan", ""),
        "JP": Entity("Japan", "JP", "JPN", "392", "Japan", ""),
        "KE": Entity("Kenya", "KE", "KEN", "404", "Kenya", ""),
        "KG": Entity("Kyrgyzstan", "KG", "KGZ", "417", "Kyrgyzstan", ""),
        "KH": Entity("Cambodia", "KH", "KHM", "116", "Cambodia", ""),
        "KI": Entity("Kiribati", "KI", "KIR", "296", "Kiribati", ""),
        "KM": Entity("Comoros", "KM", "COM", "174", "Comoros (the)", ""),
        "KN": Entity("Saint Kitts and Nevis", "KN", "KNA", "659", "Saint Kitts and Nevis", ""),
        "KP": Entity(
            "North Korea", "KP", "PRK", "408", "Korea (the Democratic People's Republic of)", ""
        ),
        "KR": Entity("South Korea", "KR", "KOR", "410", "Korea (the Republic of)", ""),
        "KW": Entity("Kuwait", "KW", "KWT", "414", "Kuwait", ""),
        "KY": Entity("Cayman Islands", "KY", "CYM", "136", "Cayman Islands (the)", "GB"),
        "KZ": Entity("Kazakhstan", "KZ", "KAZ", "398", "Kazakhstan", ""),
        "LA": Entity(
            "Lao People's Democratic Republic",
            "LA",
            "LAO",
            "418",
            "Lao People's Democratic Republic (the)",
            "",
        ),
        "LB": Entity("Lebanon", "LB", "LBN", "422", "Lebanon", ""),
        "LC": Entity("Saint Lucia", "LC", "LCA", "662", "Saint Lucia", ""),
        "LI": Entity("Liechtenstein", "LI", "LIE", "438", "Liechtenstein", ""),
        "LK": Entity("Sri Lanka", "LK", "LKA", "144", "Sri Lanka", ""),
        "LR": Entity("Liberia", "LR", "LBR", "430", "Liberia", ""),
        "LS": Entity("Lesotho", "LS", "LSO", "426", "Lesotho", ""),
        "LT": Entity("Lithuania", "LT", "LTU", "440", "Lithuania", ""),
        "LU": Entity("Luxembourg", "LU", "LUX", "442", "Luxembourg", ""),
        "LV": Entity("Latvia", "LV", "LVA", "428", "Latvia", ""),
        "LY": Entity("Libya", "LY", "LBY", "434", "Libya", ""),
        "MA": Entity("Morocco", "MA", "MAR", "504", "Morocco", ""),
        "MC": Entity("Monaco", "MC", "MCO", "492", "Monaco", ""),
        "MD": Entity("Moldova", "MD", "MDA", "498", "Moldova (the Republic of)", ""),
        "ME": Entity("Montenegro", "ME", "MNE", "499", "Montenegro", ""),
        "MF": Entity("Saint Martin", "MF", "MAF", "663", "Saint Martin (French part)", "FR"),
        "MG": Entity("Madagascar", "MG", "MDG", "450", "Madagascar", ""),
        "MH": Entity("Marshall Islands", "MH", "MHL", "584", "Marshall Islands (the)", ""),
        "MK": Entity("North Macedonia", "MK", "MKD", "807", "North Macedonia", ""),
        "ML": Entity("Mali", "ML", "MLI", "466", "Mali", ""),
        "MM": Entity("Myanmar", "MM", "MMR", "104", "Myanmar", ""),
        "MN": Entity("Mongolia", "MN", "MNG", "496", "Mongolia", ""),
        "MO": Entity("Macao", "MO", "MAC", "446", "Macao", "CN"),
        "MP": Entity(
            "Northern Mariana Islands", "MP", "MNP", "580", "Northern Mariana Islands (the)", "US"
        ),
        "MQ": Entity("Martinique", "MQ", "MTQ", "474", "Martinique", "FR"),
        "MR": Entity("Mauritania", "MR", "MRT", "478", "Mauritania", ""),
        "MS": Entity("Montserrat", "MS", "MSR", "500", "Montserrat", "GB"),
        "MT": Entity("Malta", "MT", "MLT", "470", "Malta", ""),
        "MU": Entity("Mauritius", "MU", "MUS", "480", "Mauritius", ""),
        "MV": Entity("Maldives", "MV", "MDV", "462", "Maldives", ""),
        "MW": Entity("Malawi", "MW", "MWI", "454", "Malawi", ""),
        "MX": Entity("Mexico", "MX", "MEX", "484", "Mexico", ""),
        "MY": Entity("Malaysia", "MY", "MYS", "458", "Malaysia", ""),
        "MZ": Entity("Mozambique", "MZ", "MOZ", "508", "Mozambique", ""),
        "NA": Entity("Namibia", "NA", "NAM", "516", "Namibia", ""),
        "NC": Entity("New Caledonia", "NC", "NCL", "540", "New Caledonia", "FR"),
        "NE": Entity("Niger", "NE", "NER", "562", "Niger (the)", ""),
        "NF": Entity("Norfolk Island", "NF", "NFK", "574", "Norfolk Island", "AU"),
        "NG": Entity("Nigeria", "NG", "NGA", "566", "Nigeria", ""),
        "NI": Entity("Nicaragua", "NI", "NIC", "558", "Nicaragua", ""),
        "NL": Entity("Netherlands", "NL", "NLD", "528", "Netherlands (Kingdom of the)", ""),
        "NO": Entity("Norway", "NO", "NOR", "578", "Norway", ""),
        "NP": Entity("Nepal", "NP", "NPL", "524", "Nepal", ""),
        "NR": Entity("Nauru", "NR", "NRU", "520", "Nauru", ""),
        "NU": Entity("Niue", "NU", "NIU", "570", "Niue", "NZ"),
        "NZ": Entity("New Zealand", "NZ", "NZL", "554", "New Zealand", ""),
        "OM": Entity("Oman", "OM", "OMN", "512", "Oman", ""),
        "PA": Entity("Panama", "PA", "PAN", "591", "Panama", ""),
        "PE": Entity("Peru", "PE", "PER", "604", "Peru", ""),
        "PF": Entity("French Polynesia", "PF", "PYF", "258", "French Polynesia", "FR"),
        "PG": Entity("Papua New Guinea", "PG", "PNG", "598", "Papua New Guinea", ""),
        "PH": Entity("Philippines", "PH", "PHL", "608", "Philippines (the)", ""),
        "PK": Entity("Pakistan", "PK", "PAK", "586", "Pakistan", ""),
        "PL": Entity("Poland", "PL", "POL", "616", "Poland", ""),
        "PM": Entity(
            "Saint Pierre and Miquelon", "PM", "SPM", "666", "Saint Pierre and Miquelon", "FR"
        ),
        "PN": Entity("Pitcairn", "PN", "PCN", "612", "Pitcairn", "GB"),
        "PR": Entity("Puerto Rico", "PR", "PRI", "630", "Puerto Rico", "US"),
        "PS": Entity("Palestine", "PS", "PSE", "275", "Palestine, State of", "IL"),
        "PT": Entity("Portugal", "PT", "PRT", "620", "Portugal", ""),
        "PW": Entity("Palau", "PW", "PLW", "585", "Palau", ""),
        "PY": Entity("Paraguay", "PY", "PRY", "600", "Paraguay", ""),
        "QA": Entity("Qatar", "QA", "QAT", "634", "Qatar", ""),
        "RE": Entity("Réunion", "RE", "REU", "638", "Réunion", "FR"),
        "RO": Entity("Romania", "RO", "ROU", "642", "Romania", ""),
        "RS": Entity("Serbia", "RS", "SRB", "688", "Serbia", ""),
        "RU": Entity("Russian Federation", "RU", "RUS", "643", "Russian Federation (the)", ""),
        "RW": Entity("Rwanda", "RW", "RWA", "646", "Rwanda", ""),
        "SA": Entity("Saudi Arabia", "SA", "SAU", "682", "Saudi Arabia", ""),
        "SB": Entity("Solomon Islands", "SB", "SLB", "090", "Solomon Islands", ""),
        "SC": Entity("Seychelles", "SC", "SYC", "690", "Seychelles", ""),
        "SD": Entity("Sudan", "SD", "SDN", "729", "Sudan (the)", ""),
        "SE": Entity("Sweden", "SE", "SWE", "752", "Sweden", ""),
        "SG": Entity("Singapore", "SG", "SGP", "702", "Singapore", ""),
        "SH": Entity(
            "Saint Helena", "SH", "SHN", "654", "Saint Helena, Ascension and Tristan da Cunha", "GB"
        ),
        "SI": Entity("Slovenia", "SI", "SVN", "705", "Slovenia", ""),
        "SJ": Entity("Svalbard and Jan Mayen", "SJ", "SJM", "744", "Svalbard and Jan Mayen", "NO"),
        "SK": Entity("Slovakia", "SK", "SVK", "703", "Slovakia", ""),
        "SL": Entity("Sierra Leone", "SL", "SLE", "694", "Sierra Leone", ""),
        "SM": Entity("San Marino", "SM", "SMR", "674", "San Marino", ""),
        "SN": Entity("Senegal", "SN", "SEN", "686", "Senegal", ""),
        "SO": Entity("Somalia", "SO", "SOM", "706", "Somalia", ""),
        "SR": Entity("Suriname", "SR", "SUR", "740", "Suriname", ""),
        "SS": Entity("South Sudan", "SS", "SSD", "728", "South Sudan", ""),
        "ST": Entity("Sao Tome and Principe", "ST", "STP", "678", "Sao Tome and Principe", ""),
        "SV": Entity("El Salvador", "SV", "SLV", "222", "El Salvador", ""),
        "SX": Entity("Sint Maarten", "SX", "SXM", "534", "Sint Maarten (Dutch part)", "NL"),
        "SY": Entity("Syrian Arab Republic", "SY", "SYR", "760", "Syrian Arab Republic (the)", ""),
        "SZ": Entity("Eswatini", "SZ", "SWZ", "748", "Eswatini", ""),
        "TC": Entity(
            "Turks and Caicos Islands", "TC", "TCA", "796", "Turks and Caicos Islands (the)", "GB"
        ),
        "TD": Entity("Chad", "TD", "TCD", "148", "Chad", ""),
        "TF": Entity(
            "French Southern Territories",
            "TF",
            "ATF",
            "260",
            "French Southern Territories (the)",
            "FR",
        ),
        "TG": Entity("Togo", "TG", "TGO", "768", "Togo", ""),
        "TH": Entity("Thailand", "TH", "THA", "764", "Thailand", ""),
        "TJ": Entity("Tajikistan", "TJ", "TJK", "762", "Tajikistan", ""),
        "TK": Entity("Tokelau", "TK", "TKL", "772", "Tokelau", "NZ"),
        "TL": Entity("Timor-Leste", "TL", "TLS", "626", "Timor-Leste", ""),
        "TM": Entity("Turkmenistan", "TM", "TKM", "795", "Turkmenistan", ""),
        "TN": Entity("Tunisia", "TN", "TUN", "788", "Tunisia", ""),
        "TO": Entity("Tonga", "TO", "TON", "776", "Tonga", ""),
        "TR": Entity("Türkiye", "TR", "TUR", "792", "Türkiye", ""),
        "TT": Entity("Trinidad and Tobago", "TT", "TTO", "780", "Trinidad and Tobago", ""),
        "TV": Entity("Tuvalu", "TV", "TUV", "798", "Tuvalu", ""),
        "TW": Entity("Taiwan", "TW", "TWN", "158", "Taiwan (Province of China)", ""),
        "TZ": Entity("Tanzania", "TZ", "TZA", "834", "Tanzania, the United Republic of", ""),
        "UA": Entity("Ukraine", "UA", "UKR", "804", "Ukraine", ""),
        "UG": Entity("Uganda", "UG", "UGA", "800", "Uganda", ""),
        "UM": Entity(
            "United States Minor Outlying Islands",
            "UM",
            "UMI",
            "581",
            "United States Minor Outlying Islands (the)",
            "US",
        ),
        "US": Entity("United States", "US", "USA", "840", "United States of America (the)", ""),
        "UY": Entity("Uruguay", "UY", "URY", "858", "Uruguay", ""),
        "UZ": Entity("Uzbekistan", "UZ", "UZB", "860", "Uzbekistan", ""),
        "VA": Entity("Holy See", "VA", "VAT", "336", "Holy See (the)", ""),
        "VC": Entity(
            "Saint Vincent and the Grenadines",
            "VC",
            "VCT",
            "670",
            "Saint Vincent and the Grenadines",
            "",
        ),
        "VE": Entity("Venezuela", "VE", "VEN", "862", "Venezuela (Bolivarian Republic of)", ""),
        "VG": Entity(
            "Virgin Islands (British)", "VG", "VGB", "092", "Virgin Islands (United Kingdom)", "GB"
        ),
        "VI": Entity(
            "Virgin Islands (U.S.)", "VI", "VIR", "850", "Virgin Islands (United States)", "US"
        ),
        "VN": Entity("Viet Nam", "VN", "VNM", "704", "Viet Nam", ""),
        "VU": Entity("Vanuatu", "VU", "VUT", "548", "Vanuatu", ""),
        "WF": Entity("Wallis and Futuna", "WF", "WLF", "876", "Wallis and Futuna", "FR"),
        "WS": Entity("Samoa", "WS", "WSM", "882", "Samoa", ""),
        "YE": Entity("Yemen", "YE", "YEM", "887", "Yemen", ""),
        "YT": Entity("Mayotte", "YT", "MYT", "175", "Mayotte", "FR"),
        "ZA": Entity("South Africa", "ZA", "ZAF", "710", "South Africa", ""),
        "ZM": Entity("Zambia", "ZM", "ZMB", "894", "Zambia", ""),
        "ZW": Entity("Zimbabwe", "ZW", "ZWE", "716", "Zimbabwe", ""),
    }

    def __str__(self) -> str:
        return "ISO 3166-1 entities"
