"""ISO 3166-2 AZ standard representation.

References:
  - https://en.wikipedia.org/wiki/ISO_3166-2
  - https://www.iso.org/obp/ui/#iso:code:3166:AZ
"""

from iso_standards.base import EntityCollection
from iso_standards.iso3166.types import Iso3166_2 as Entity


class Iso3166_2(EntityCollection):
    __slots__ = ()

    entities = {
        "AZ-ABS": (Entity("Abşeron", "AZ-ABS", "RAYON", "az", ""),),
        "AZ-AGA": (Entity("Ağstafa", "AZ-AGA", "RAYON", "az", ""),),
        "AZ-AGC": (Entity("Ağcabədi", "AZ-AGC", "RAYON", "az", ""),),
        "AZ-AGM": (Entity("Ağdam", "AZ-AGM", "RAYON", "az", ""),),
        "AZ-AGS": (Entity("Ağdaş", "AZ-AGS", "RAYON", "az", ""),),
        "AZ-AGU": (Entity("Ağsu", "AZ-AGU", "RAYON", "az", ""),),
        "AZ-AST": (Entity("Astara", "AZ-AST", "RAYON", "az", ""),),
        "AZ-BA": (Entity("Bakı", "AZ-BA", "MUNICIPALITY", "az", ""),),
        "AZ-BAB": (Entity("Babək", "AZ-BAB", "RAYON", "az", "AZ-NX"),),
        "AZ-BAL": (Entity("Balakən", "AZ-BAL", "RAYON", "az", ""),),
        "AZ-BAR": (Entity("Bərdə", "AZ-BAR", "RAYON", "az", ""),),
        "AZ-BEY": (Entity("Beyləqan", "AZ-BEY", "RAYON", "az", ""),),
        "AZ-BIL": (Entity("Biləsuvar", "AZ-BIL", "RAYON", "az", ""),),
        "AZ-CAB": (Entity("Cəbrayıl", "AZ-CAB", "RAYON", "az", ""),),
        "AZ-CAL": (Entity("Cəlilabad", "AZ-CAL", "RAYON", "az", ""),),
        "AZ-CUL": (Entity("Culfa", "AZ-CUL", "RAYON", "az", "AZ-NX"),),
        "AZ-DAS": (Entity("Daşkəsən", "AZ-DAS", "RAYON", "az", ""),),
        "AZ-FUZ": (Entity("Füzuli", "AZ-FUZ", "RAYON", "az", ""),),
        "AZ-GA": (Entity("Gəncə", "AZ-GA", "MUNICIPALITY", "az", ""),),
        "AZ-GAD": (Entity("Gədəbəy", "AZ-GAD", "RAYON", "az", ""),),
        "AZ-GOR": (Entity("Goranboy", "AZ-GOR", "RAYON", "az", ""),),
        "AZ-GOY": (Entity("Göyçay", "AZ-GOY", "RAYON", "az", ""),),
        "AZ-GYG": (Entity("Göygöl", "AZ-GYG", "RAYON", "az", ""),),
        "AZ-HAC": (Entity("Hacıqabul", "AZ-HAC", "RAYON", "az", ""),),
        "AZ-IMI": (Entity("İmişli", "AZ-IMI", "RAYON", "az", ""),),
        "AZ-ISM": (Entity("İsmayıllı", "AZ-ISM", "RAYON", "az", ""),),
        "AZ-KAL": (Entity("Kəlbəcər", "AZ-KAL", "RAYON", "az", ""),),
        "AZ-KAN": (Entity("Kǝngǝrli", "AZ-KAN", "RAYON", "az", "AZ-NX"),),
        "AZ-KUR": (Entity("Kürdəmir", "AZ-KUR", "RAYON", "az", ""),),
        "AZ-LA": (Entity("Lənkəran", "AZ-LA", "MUNICIPALITY", "az", ""),),
        "AZ-LAC": (Entity("Laçın", "AZ-LAC", "RAYON", "az", ""),),
        "AZ-LAN": (Entity("Lənkəran", "AZ-LAN", "RAYON", "az", ""),),
        "AZ-LER": (Entity("Lerik", "AZ-LER", "RAYON", "az", ""),),
        "AZ-MAS": (Entity("Masallı", "AZ-MAS", "RAYON", "az", ""),),
        "AZ-MI": (Entity("Mingəçevir", "AZ-MI", "MUNICIPALITY", "az", ""),),
        "AZ-NA": (Entity("Naftalan", "AZ-NA", "MUNICIPALITY", "az", ""),),
        "AZ-NEF": (Entity("Neftçala", "AZ-NEF", "RAYON", "az", ""),),
        "AZ-NV": (Entity("Naxçıvan", "AZ-NV", "MUNICIPALITY", "az", "AZ-NX"),),
        "AZ-NX": (Entity("Naxçıvan", "AZ-NX", "AUTONOMOUS REPUBLIC", "az", ""),),
        "AZ-OGU": (Entity("Oğuz", "AZ-OGU", "RAYON", "az", ""),),
        "AZ-ORD": (Entity("Ordubad", "AZ-ORD", "RAYON", "az", "AZ-NX"),),
        "AZ-QAB": (Entity("Qəbələ", "AZ-QAB", "RAYON", "az", ""),),
        "AZ-QAX": (Entity("Qax", "AZ-QAX", "RAYON", "az", ""),),
        "AZ-QAZ": (Entity("Qazax", "AZ-QAZ", "RAYON", "az", ""),),
        "AZ-QBA": (Entity("Quba", "AZ-QBA", "RAYON", "az", ""),),
        "AZ-QBI": (Entity("Qubadlı", "AZ-QBI", "RAYON", "az", ""),),
        "AZ-QOB": (Entity("Qobustan", "AZ-QOB", "RAYON", "az", ""),),
        "AZ-QUS": (Entity("Qusar", "AZ-QUS", "RAYON", "az", ""),),
        "AZ-SA": (Entity("Şəki", "AZ-SA", "MUNICIPALITY", "az", ""),),
        "AZ-SAB": (Entity("Sabirabad", "AZ-SAB", "RAYON", "az", ""),),
        "AZ-SAD": (Entity("Sədərək", "AZ-SAD", "RAYON", "az", "AZ-NX"),),
        "AZ-SAH": (Entity("Şahbuz", "AZ-SAH", "RAYON", "az", "AZ-NX"),),
        "AZ-SAK": (Entity("Şəki", "AZ-SAK", "RAYON", "az", ""),),
        "AZ-SAL": (Entity("Salyan", "AZ-SAL", "RAYON", "az", ""),),
        "AZ-SAR": (Entity("Şərur", "AZ-SAR", "RAYON", "az", "AZ-NX"),),
        "AZ-SAT": (Entity("Saatlı", "AZ-SAT", "RAYON", "az", ""),),
        "AZ-SBN": (Entity("Şabran", "AZ-SBN", "RAYON", "az", ""),),
        "AZ-SIY": (Entity("Siyəzən", "AZ-SIY", "RAYON", "az", ""),),
        "AZ-SKR": (Entity("Şəmkir", "AZ-SKR", "RAYON", "az", ""),),
        "AZ-SM": (Entity("Sumqayıt", "AZ-SM", "MUNICIPALITY", "az", ""),),
        "AZ-SMI": (Entity("Şamaxı", "AZ-SMI", "RAYON", "az", ""),),
        "AZ-SMX": (Entity("Samux", "AZ-SMX", "RAYON", "az", ""),),
        "AZ-SR": (Entity("Şirvan", "AZ-SR", "MUNICIPALITY", "az", ""),),
        "AZ-SUS": (Entity("Şuşa", "AZ-SUS", "RAYON", "az", ""),),
        "AZ-TAR": (Entity("Tərtər", "AZ-TAR", "RAYON", "az", ""),),
        "AZ-TOV": (Entity("Tovuz", "AZ-TOV", "RAYON", "az", ""),),
        "AZ-UCA": (Entity("Ucar", "AZ-UCA", "RAYON", "az", ""),),
        "AZ-XA": (Entity("Xankəndi", "AZ-XA", "MUNICIPALITY", "az", ""),),
        "AZ-XAC": (Entity("Xaçmaz", "AZ-XAC", "RAYON", "az", ""),),
        "AZ-XCI": (Entity("Xocalı", "AZ-XCI", "RAYON", "az", ""),),
        "AZ-XIZ": (Entity("Xızı", "AZ-XIZ", "RAYON", "az", ""),),
        "AZ-XVD": (Entity("Xocavənd", "AZ-XVD", "RAYON", "az", ""),),
        "AZ-YAR": (Entity("Yardımlı", "AZ-YAR", "RAYON", "az", ""),),
        "AZ-YE": (Entity("Yevlax", "AZ-YE", "MUNICIPALITY", "az", ""),),
        "AZ-YEV": (Entity("Yevlax", "AZ-YEV", "RAYON", "az", ""),),
        "AZ-ZAN": (Entity("Zəngilan", "AZ-ZAN", "RAYON", "az", ""),),
        "AZ-ZAQ": (Entity("Zaqatala", "AZ-ZAQ", "RAYON", "az", ""),),
        "AZ-ZAR": (Entity("Zərdab", "AZ-ZAR", "RAYON", "az", ""),),
    }
