"""ISO 3166-2 EE standard representation.

References:
  - https://en.wikipedia.org/wiki/ISO_3166-2
  - https://www.iso.org/obp/ui/#iso:code:3166:EE
"""

from iso_standards.base import EntityCollection
from iso_standards.iso3166.types import Iso3166_2 as Entity


class Iso3166_2(EntityCollection):
    __slots__ = ()

    entities = {
        "EE-130": (Entity("Alutaguse", "EE-130", "RURAL MUNICIPALITY", "et", "EE-45"),),
        "EE-141": (Entity("Anija", "EE-141", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-142": (Entity("Antsla", "EE-142", "RURAL MUNICIPALITY", "et", "EE-87"),),
        "EE-171": (Entity("Elva", "EE-171", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-184": (Entity("Haapsalu", "EE-184", "URBAN MUNICIPALITY", "et", "EE-56"),),
        "EE-191": (Entity("Haljala", "EE-191", "RURAL MUNICIPALITY", "et", "EE-60"),),
        "EE-198": (Entity("Harku", "EE-198", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-205": (Entity("Hiiumaa", "EE-205", "RURAL MUNICIPALITY", "et", "EE-39"),),
        "EE-214": (Entity("Häädemeeste", "EE-214", "RURAL MUNICIPALITY", "et", "EE-68"),),
        "EE-245": (Entity("Jõelähtme", "EE-245", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-247": (Entity("Jõgeva", "EE-247", "RURAL MUNICIPALITY", "et", "EE-50"),),
        "EE-251": (Entity("Jõhvi", "EE-251", "RURAL MUNICIPALITY", "et", "EE-45"),),
        "EE-255": (Entity("Järva", "EE-255", "RURAL MUNICIPALITY", "et", "EE-52"),),
        "EE-272": (Entity("Kadrina", "EE-272", "RURAL MUNICIPALITY", "et", "EE-60"),),
        "EE-283": (Entity("Kambja", "EE-283", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-284": (Entity("Kanepi", "EE-284", "RURAL MUNICIPALITY", "et", "EE-64"),),
        "EE-291": (Entity("Kastre", "EE-291", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-293": (Entity("Kehtna", "EE-293", "RURAL MUNICIPALITY", "et", "EE-71"),),
        "EE-296": (Entity("Keila", "EE-296", "URBAN MUNICIPALITY", "et", "EE-37"),),
        "EE-303": (Entity("Kihnu", "EE-303", "RURAL MUNICIPALITY", "et", "EE-68"),),
        "EE-305": (Entity("Kiili", "EE-305", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-317": (Entity("Kohila", "EE-317", "RURAL MUNICIPALITY", "et", "EE-71"),),
        "EE-321": (Entity("Kohtla-Järve", "EE-321", "URBAN MUNICIPALITY", "et", "EE-45"),),
        "EE-338": (Entity("Kose", "EE-338", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-353": (Entity("Kuusalu", "EE-353", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-37": (Entity("Harjumaa", "EE-37", "COUNTY", "et", ""),),
        "EE-39": (Entity("Hiiumaa", "EE-39", "COUNTY", "et", ""),),
        "EE-424": (Entity("Loksa", "EE-424", "URBAN MUNICIPALITY", "et", "EE-37"),),
        "EE-430": (Entity("Lääneranna", "EE-430", "RURAL MUNICIPALITY", "et", "EE-68"),),
        "EE-431": (Entity("Lääne-Harju", "EE-431", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-432": (Entity("Luunja", "EE-432", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-441": (Entity("Lääne-Nigula", "EE-441", "RURAL MUNICIPALITY", "et", "EE-56"),),
        "EE-442": (Entity("Lüganuse", "EE-442", "RURAL MUNICIPALITY", "et", "EE-45"),),
        "EE-446": (Entity("Maardu", "EE-446", "URBAN MUNICIPALITY", "et", "EE-37"),),
        "EE-45": (Entity("Ida-Virumaa", "EE-45", "COUNTY", "et", ""),),
        "EE-478": (Entity("Muhu", "EE-478", "RURAL MUNICIPALITY", "et", "EE-74"),),
        "EE-480": (Entity("Mulgi", "EE-480", "RURAL MUNICIPALITY", "et", "EE-84"),),
        "EE-486": (Entity("Mustvee", "EE-486", "RURAL MUNICIPALITY", "et", "EE-50"),),
        "EE-50": (Entity("Jõgevamaa", "EE-50", "COUNTY", "et", ""),),
        "EE-503": (Entity("Märjamaa", "EE-503", "RURAL MUNICIPALITY", "et", "EE-71"),),
        "EE-511": (Entity("Narva", "EE-511", "URBAN MUNICIPALITY", "et", "EE-45"),),
        "EE-514": (Entity("Narva-Jõesuu", "EE-514", "URBAN MUNICIPALITY", "et", "EE-45"),),
        "EE-52": (Entity("Järvamaa", "EE-52", "COUNTY", "et", ""),),
        "EE-528": (Entity("Nõo", "EE-528", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-557": (Entity("Otepää", "EE-557", "RURAL MUNICIPALITY", "et", "EE-81"),),
        "EE-56": (Entity("Läänemaa", "EE-56", "COUNTY", "et", ""),),
        "EE-567": (Entity("Paide", "EE-567", "URBAN MUNICIPALITY", "et", "EE-52"),),
        "EE-586": (Entity("Peipsiääre", "EE-586", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-60": (Entity("Lääne-Virumaa", "EE-60", "COUNTY", "et", ""),),
        "EE-615": (Entity("Põhja-Sakala", "EE-615", "RURAL MUNICIPALITY", "et", "EE-84"),),
        "EE-618": (Entity("Põltsamaa", "EE-618", "RURAL MUNICIPALITY", "et", "EE-50"),),
        "EE-622": (Entity("Põlva", "EE-622", "RURAL MUNICIPALITY", "et", "EE-64"),),
        "EE-624": (Entity("Pärnu", "EE-624", "URBAN MUNICIPALITY", "et", "EE-68"),),
        "EE-638": (Entity("Põhja-Pärnumaa", "EE-638", "RURAL MUNICIPALITY", "et", "EE-68"),),
        "EE-64": (Entity("Põlvamaa", "EE-64", "COUNTY", "et", ""),),
        "EE-651": (Entity("Raasiku", "EE-651", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-653": (Entity("Rae", "EE-653", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-661": (Entity("Rakvere", "EE-661", "RURAL MUNICIPALITY", "et", "EE-60"),),
        "EE-663": (Entity("Rakvere", "EE-663", "URBAN MUNICIPALITY", "et", "EE-60"),),
        "EE-668": (Entity("Rapla", "EE-668", "RURAL MUNICIPALITY", "et", "EE-71"),),
        "EE-68": (Entity("Pärnumaa", "EE-68", "COUNTY", "et", ""),),
        "EE-689": (Entity("Ruhnu", "EE-689", "RURAL MUNICIPALITY", "et", "EE-74"),),
        "EE-698": (Entity("Rõuge", "EE-698", "RURAL MUNICIPALITY", "et", "EE-87"),),
        "EE-708": (Entity("Räpina", "EE-708", "RURAL MUNICIPALITY", "et", "EE-64"),),
        "EE-71": (Entity("Raplamaa", "EE-71", "COUNTY", "et", ""),),
        "EE-712": (Entity("Saarde", "EE-712", "RURAL MUNICIPALITY", "et", "EE-68"),),
        "EE-714": (Entity("Saaremaa", "EE-714", "RURAL MUNICIPALITY", "et", "EE-74"),),
        "EE-719": (Entity("Saku", "EE-719", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-726": (Entity("Saue", "EE-726", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-732": (Entity("Setomaa", "EE-732", "RURAL MUNICIPALITY", "et", "EE-87"),),
        "EE-735": (Entity("Sillamäe", "EE-735", "URBAN MUNICIPALITY", "et", "EE-45"),),
        "EE-74": (Entity("Saaremaa", "EE-74", "COUNTY", "et", ""),),
        "EE-784": (Entity("Tallinn", "EE-784", "URBAN MUNICIPALITY", "et", "EE-37"),),
        "EE-79": (Entity("Tartumaa", "EE-79", "COUNTY", "et", ""),),
        "EE-792": (Entity("Tapa", "EE-792", "RURAL MUNICIPALITY", "et", "EE-60"),),
        "EE-793": (Entity("Tartu", "EE-793", "URBAN MUNICIPALITY", "et", "EE-79"),),
        "EE-796": (Entity("Tartu", "EE-796", "RURAL MUNICIPALITY", "et", "EE-79"),),
        "EE-803": (Entity("Toila", "EE-803", "RURAL MUNICIPALITY", "et", "EE-45"),),
        "EE-809": (Entity("Tori", "EE-809", "RURAL MUNICIPALITY", "et", "EE-68"),),
        "EE-81": (Entity("Valgamaa", "EE-81", "COUNTY", "et", ""),),
        "EE-824": (Entity("Tõrva", "EE-824", "RURAL MUNICIPALITY", "et", "EE-81"),),
        "EE-834": (Entity("Türi", "EE-834", "RURAL MUNICIPALITY", "et", "EE-52"),),
        "EE-84": (Entity("Viljandimaa", "EE-84", "COUNTY", "et", ""),),
        "EE-855": (Entity("Valga", "EE-855", "RURAL MUNICIPALITY", "et", "EE-81"),),
        "EE-87": (Entity("Võrumaa", "EE-87", "COUNTY", "et", ""),),
        "EE-890": (Entity("Viimsi", "EE-890", "RURAL MUNICIPALITY", "et", "EE-37"),),
        "EE-897": (Entity("Viljandi", "EE-897", "URBAN MUNICIPALITY", "et", "EE-84"),),
        "EE-899": (Entity("Viljandi", "EE-899", "RURAL MUNICIPALITY", "et", "EE-84"),),
        "EE-901": (Entity("Vinni", "EE-901", "RURAL MUNICIPALITY", "et", "EE-60"),),
        "EE-903": (Entity("Viru-Nigula", "EE-903", "RURAL MUNICIPALITY", "et", "EE-60"),),
        "EE-907": (Entity("Vormsi", "EE-907", "RURAL MUNICIPALITY", "et", "EE-56"),),
        "EE-917": (Entity("Võru", "EE-917", "RURAL MUNICIPALITY", "et", "EE-87"),),
        "EE-919": (Entity("Võru", "EE-919", "URBAN MUNICIPALITY", "et", "EE-87"),),
        "EE-928": (Entity("Väike-Maarja", "EE-928", "RURAL MUNICIPALITY", "et", "EE-60"),),
    }
