"""ISO 3166-2 GB standard representation.

References:
  - https://en.wikipedia.org/wiki/ISO_3166-2
  - https://www.iso.org/obp/ui/#iso:code:3166:GB
"""

from iso_standards.base import EntityCollection
from iso_standards.iso3166.types import Iso3166_2 as Entity


class Iso3166_2(EntityCollection):
    __slots__ = ()

    entities = {
        "GB-ABC": (Entity("Armagh City", "GB-ABC", "DISTRICT", "en", "GB-NIR"),),
        "GB-ABD": (Entity("Aberdeenshire", "GB-ABD", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-ABE": (Entity("Aberdeen City", "GB-ABE", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-AGB": (Entity("Argyll and Bute", "GB-AGB", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-AGY": (Entity("Isle of Anglesey", "GB-AGY", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-AND": (Entity("Ards and North Down", "GB-AND", "DISTRICT", "en", "GB-NIR"),),
        "GB-ANN": (Entity("Antrim and Newtownabbey", "GB-ANN", "DISTRICT", "en", "GB-NIR"),),
        "GB-ANS": (Entity("Angus", "GB-ANS", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-BAS": (
            Entity("Bath and North East Somerset", "GB-BAS", "UNITARY AUTHORITY", "en", "GB-ENG"),
        ),
        "GB-BBD": (Entity("Blackburn with Darwen", "GB-BBD", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BCP": (Entity("Bournemouth", "GB-BCP", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BDF": (Entity("Bedford", "GB-BDF", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BDG": (Entity("Barking and Dagenham", "GB-BDG", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-BEN": (Entity("Brent", "GB-BEN", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-BEX": (Entity("Bexley", "GB-BEX", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-BFS": (Entity("Belfast City", "GB-BFS", "DISTRICT", "en", "GB-NIR"),),
        "GB-BGE": (Entity("Bridgend", "GB-BGE", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-BGW": (Entity("Blaenau Gwent", "GB-BGW", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-BIR": (Entity("Birmingham", "GB-BIR", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-BKM": (Entity("Buckinghamshire", "GB-BKM", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BNE": (Entity("Barnet", "GB-BNE", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-BNH": (Entity("Brighton and Hove", "GB-BNH", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BNS": (Entity("Barnsley", "GB-BNS", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-BOL": (Entity("Bolton", "GB-BOL", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-BPL": (Entity("Blackpool", "GB-BPL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BRC": (Entity("Bracknell Forest", "GB-BRC", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BRD": (Entity("Bradford", "GB-BRD", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-BRY": (Entity("Bromley", "GB-BRY", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-BST": (Entity("Bristol", "GB-BST", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-BUR": (Entity("Bury", "GB-BUR", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-CAM": (Entity("Cambridgeshire", "GB-CAM", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-CAY": (Entity("Caerphilly", "GB-CAY", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-CBF": (Entity("Central Bedfordshire", "GB-CBF", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-CCG": (Entity("Causeway Coast and Glens", "GB-CCG", "DISTRICT", "en", "GB-NIR"),),
        "GB-CGN": (Entity("Ceredigion", "GB-CGN", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-CHE": (Entity("Cheshire East", "GB-CHE", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-CHW": (
            Entity("Cheshire West and Chester", "GB-CHW", "UNITARY AUTHORITY", "en", "GB-ENG"),
        ),
        "GB-CLD": (Entity("Calderdale", "GB-CLD", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-CLK": (Entity("Clackmannanshire", "GB-CLK", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-CMA": (Entity("Cumbria", "GB-CMA", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-CMD": (Entity("Camden", "GB-CMD", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-CMN": (Entity("Carmarthenshire", "GB-CMN", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-CON": (Entity("Cornwall", "GB-CON", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-COV": (Entity("Coventry", "GB-COV", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-CRF": (Entity("Cardiff", "GB-CRF", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-CRY": (Entity("Croydon", "GB-CRY", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-CWY": (Entity("Conwy", "GB-CWY", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-DAL": (Entity("Darlington", "GB-DAL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-DBY": (Entity("Derbyshire", "GB-DBY", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-DEN": (Entity("Denbighshire", "GB-DEN", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-DER": (Entity("Derby", "GB-DER", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-DEV": (Entity("Devon", "GB-DEV", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-DGY": (Entity("Dumfries and Galloway", "GB-DGY", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-DNC": (Entity("Doncaster", "GB-DNC", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-DND": (Entity("Dundee City", "GB-DND", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-DOR": (Entity("Dorset", "GB-DOR", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-DRS": (Entity("Derry and Strabane", "GB-DRS", "DISTRICT", "en", "GB-NIR"),),
        "GB-DUD": (Entity("Dudley", "GB-DUD", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-DUR": (Entity("Durham", "GB-DUR", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-EAL": (Entity("Ealing", "GB-EAL", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-EAY": (Entity("East Ayrshire", "GB-EAY", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-EDH": (Entity("Edinburgh", "GB-EDH", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-EDU": (Entity("East Dunbartonshire", "GB-EDU", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-ELN": (Entity("East Lothian", "GB-ELN", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-ELS": (Entity("Eilean Siar", "GB-ELS", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-ENF": (Entity("Enfield", "GB-ENF", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-ENG": (Entity("England", "GB-ENG", "COUNTRY", "en", ""),),
        "GB-ERW": (Entity("East Renfrewshire", "GB-ERW", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-ERY": (
            Entity("East Riding of Yorkshire", "GB-ERY", "UNITARY AUTHORITY", "en", "GB-ENG"),
        ),
        "GB-ESS": (Entity("Essex", "GB-ESS", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-ESX": (Entity("East Sussex", "GB-ESX", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-FAL": (Entity("Falkirk", "GB-FAL", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-FIF": (Entity("Fife", "GB-FIF", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-FLN": (Entity("Flintshire", "GB-FLN", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-FMO": (Entity("Fermanagh and Omagh", "GB-FMO", "DISTRICT", "en", "GB-NIR"),),
        "GB-GAT": (Entity("Gateshead", "GB-GAT", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-GLG": (Entity("Glasgow City", "GB-GLG", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-GLS": (Entity("Gloucestershire", "GB-GLS", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-GRE": (Entity("Greenwich", "GB-GRE", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-GWN": (Entity("Gwynedd", "GB-GWN", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-HAL": (Entity("Halton", "GB-HAL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-HAM": (Entity("Hampshire", "GB-HAM", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-HAV": (Entity("Havering", "GB-HAV", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-HCK": (Entity("Hackney", "GB-HCK", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-HEF": (Entity("Herefordshire", "GB-HEF", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-HIL": (Entity("Hillingdon", "GB-HIL", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-HLD": (Entity("Highland", "GB-HLD", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-HMF": (Entity("Hammersmith and Fulham", "GB-HMF", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-HNS": (Entity("Hounslow", "GB-HNS", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-HPL": (Entity("Hartlepool", "GB-HPL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-HRT": (Entity("Hertfordshire", "GB-HRT", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-HRW": (Entity("Harrow", "GB-HRW", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-HRY": (Entity("Haringey", "GB-HRY", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-IOS": (Entity("Isles of Scilly", "GB-IOS", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-IOW": (Entity("Isle of Wight", "GB-IOW", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-ISL": (Entity("Islington", "GB-ISL", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-IVC": (Entity("Inverclyde", "GB-IVC", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-KEC": (Entity("Kensington and Chelsea", "GB-KEC", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-KEN": (Entity("Kent", "GB-KEN", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-KHL": (Entity("Kingston upon Hull", "GB-KHL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-KIR": (Entity("Kirklees", "GB-KIR", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-KTT": (Entity("Kingston upon Thames", "GB-KTT", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-KWL": (Entity("Knowsley", "GB-KWL", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-LAN": (Entity("Lancashire", "GB-LAN", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-LBC": (Entity("Lisburn and Castlereagh", "GB-LBC", "DISTRICT", "en", "GB-NIR"),),
        "GB-LBH": (Entity("Lambeth", "GB-LBH", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-LCE": (Entity("Leicester", "GB-LCE", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-LDS": (Entity("Leeds", "GB-LDS", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-LEC": (Entity("Leicestershire", "GB-LEC", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-LEW": (Entity("Lewisham", "GB-LEW", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-LIN": (Entity("Lincolnshire", "GB-LIN", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-LIV": (Entity("Liverpool", "GB-LIV", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-LND": (Entity("London", "GB-LND", "CITY CORPORATION", "en", "GB-ENG"),),
        "GB-LUT": (Entity("Luton", "GB-LUT", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-MAN": (Entity("Manchester", "GB-MAN", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-MDB": (Entity("Middlesbrough", "GB-MDB", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-MDW": (Entity("Medway", "GB-MDW", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-MEA": (Entity("Mid and East Antrim", "GB-MEA", "DISTRICT", "en", "GB-NIR"),),
        "GB-MIK": (Entity("Milton Keynes", "GB-MIK", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-MLN": (Entity("Midlothian", "GB-MLN", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-MON": (Entity("Monmouthshire", "GB-MON", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-MRT": (Entity("Merton", "GB-MRT", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-MRY": (Entity("Moray", "GB-MRY", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-MTY": (Entity("Merthyr Tydfil", "GB-MTY", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-MUL": (Entity("Mid-Ulster", "GB-MUL", "DISTRICT", "en", "GB-NIR"),),
        "GB-NAY": (Entity("North Ayrshire", "GB-NAY", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-NBL": (Entity("Northumberland", "GB-NBL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-NEL": (
            Entity("North East Lincolnshire", "GB-NEL", "UNITARY AUTHORITY", "en", "GB-ENG"),
        ),
        "GB-NET": (
            Entity("Newcastle upon Tyne", "GB-NET", "METROPOLITAN DISTRICT", "en", "GB-ENG"),
        ),
        "GB-NFK": (Entity("Norfolk", "GB-NFK", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-NGM": (Entity("Nottingham", "GB-NGM", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-NIR": (Entity("Northern Ireland", "GB-NIR", "PROVINCE", "en", ""),),
        "GB-NLK": (Entity("North Lanarkshire", "GB-NLK", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-NLN": (Entity("North Lincolnshire", "GB-NLN", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-NMD": (Entity("Newry", "GB-NMD", "DISTRICT", "en", "GB-NIR"),),
        "GB-NNH": (
            Entity("North Northamptonshire", "GB-NNH", "UNITARY AUTHORITY", "en", "GB-ENG"),
        ),
        "GB-NSM": (Entity("North Somerset", "GB-NSM", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-NTL": (Entity("Neath Port Talbot", "GB-NTL", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-NTT": (Entity("Nottinghamshire", "GB-NTT", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-NTY": (Entity("North Tyneside", "GB-NTY", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-NWM": (Entity("Newham", "GB-NWM", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-NWP": (Entity("Newport", "GB-NWP", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-NYK": (Entity("North Yorkshire", "GB-NYK", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-OLD": (Entity("Oldham", "GB-OLD", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-ORK": (Entity("Orkney Islands", "GB-ORK", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-OXF": (Entity("Oxfordshire", "GB-OXF", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-PEM": (Entity("Pembrokeshire", "GB-PEM", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-PKN": (Entity("Perth and Kinross", "GB-PKN", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-PLY": (Entity("Plymouth", "GB-PLY", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-POR": (Entity("Portsmouth", "GB-POR", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-POW": (Entity("Powys", "GB-POW", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-PTE": (Entity("Peterborough", "GB-PTE", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-RCC": (Entity("Redcar and Cleveland", "GB-RCC", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-RCH": (Entity("Rochdale", "GB-RCH", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-RCT": (Entity("Rhondda Cynon Taff", "GB-RCT", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-RDB": (Entity("Redbridge", "GB-RDB", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-RDG": (Entity("Reading", "GB-RDG", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-RFW": (Entity("Renfrewshire", "GB-RFW", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-RIC": (Entity("Richmond upon Thames", "GB-RIC", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-ROT": (Entity("Rotherham", "GB-ROT", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-RUT": (Entity("Rutland", "GB-RUT", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-SAW": (Entity("Sandwell", "GB-SAW", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SAY": (Entity("South Ayrshire", "GB-SAY", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-SCB": (Entity("Scottish Borders", "GB-SCB", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-SCT": (Entity("Scotland", "GB-SCT", "COUNTRY", "en", ""),),
        "GB-SFK": (Entity("Suffolk", "GB-SFK", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-SFT": (Entity("Sefton", "GB-SFT", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SGC": (Entity("South Gloucestershire", "GB-SGC", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-SHF": (Entity("Sheffield", "GB-SHF", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SHN": (Entity("St. Helens", "GB-SHN", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SHR": (Entity("Shropshire", "GB-SHR", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-SKP": (Entity("Stockport", "GB-SKP", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SLF": (Entity("Salford", "GB-SLF", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SLG": (Entity("Slough", "GB-SLG", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-SLK": (Entity("South Lanarkshire", "GB-SLK", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-SND": (Entity("Sunderland", "GB-SND", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SOL": (Entity("Solihull", "GB-SOL", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SOM": (Entity("Somerset", "GB-SOM", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-SOS": (Entity("Southend-on-Sea", "GB-SOS", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-SRY": (Entity("Surrey", "GB-SRY", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-STE": (Entity("Stoke-on-Trent", "GB-STE", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-STG": (Entity("Stirling", "GB-STG", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-STH": (Entity("Southampton", "GB-STH", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-STN": (Entity("Sutton", "GB-STN", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-STS": (Entity("Staffordshire", "GB-STS", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-STT": (Entity("Stockton-on-Tees", "GB-STT", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-STY": (Entity("South Tyneside", "GB-STY", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-SWA": (Entity("Swansea", "GB-SWA", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-SWD": (Entity("Swindon", "GB-SWD", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-SWK": (Entity("Southwark", "GB-SWK", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-TAM": (Entity("Tameside", "GB-TAM", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-TFW": (Entity("Telford and Wrekin", "GB-TFW", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-THR": (Entity("Thurrock", "GB-THR", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-TOB": (Entity("Torbay", "GB-TOB", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-TOF": (Entity("Torfaen", "GB-TOF", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-TRF": (Entity("Trafford", "GB-TRF", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-TWH": (Entity("Tower Hamlets", "GB-TWH", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-VGL": (Entity("Vale of Glamorgan", "GB-VGL", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-WAR": (Entity("Warwickshire", "GB-WAR", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-WBK": (Entity("West Berkshire", "GB-WBK", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-WDU": (Entity("West Dunbartonshire", "GB-WDU", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-WFT": (Entity("Waltham Forest", "GB-WFT", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-WGN": (Entity("Wigan", "GB-WGN", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-WIL": (Entity("Wiltshire", "GB-WIL", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-WKF": (Entity("Wakefield", "GB-WKF", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-WLL": (Entity("Walsall", "GB-WLL", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-WLN": (Entity("West Lothian", "GB-WLN", "COUNCIL AREA", "en", "GB-SCT"),),
        "GB-WLS": (Entity("Wales", "GB-WLS", "COUNTRY", "en", ""),),
        "GB-WLV": (Entity("Wolverhampton", "GB-WLV", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-WND": (Entity("Wandsworth", "GB-WND", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-WNH": (Entity("West Northamptonshire", "GB-WNH", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-WNM": (
            Entity("Windsor and Maidenhead", "GB-WNM", "UNITARY AUTHORITY", "en", "GB-ENG"),
        ),
        "GB-WOK": (Entity("Wokingham", "GB-WOK", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-WOR": (Entity("Worcestershire", "GB-WOR", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-WRL": (Entity("Wirral", "GB-WRL", "METROPOLITAN DISTRICT", "en", "GB-ENG"),),
        "GB-WRT": (Entity("Warrington", "GB-WRT", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-WRX": (Entity("Wrexham", "GB-WRX", "UNITARY AUTHORITY", "en", "GB-WLS"),),
        "GB-WSM": (Entity("Westminster", "GB-WSM", "LONDON BOROUGH", "en", "GB-ENG"),),
        "GB-WSX": (Entity("West Sussex", "GB-WSX", "TWO-TIER COUNTY", "en", "GB-ENG"),),
        "GB-YOR": (Entity("York", "GB-YOR", "UNITARY AUTHORITY", "en", "GB-ENG"),),
        "GB-ZET": (Entity("Shetland Islands", "GB-ZET", "COUNCIL AREA", "en", "GB-SCT"),),
    }
