"""ISO 3166-2 MT standard representation.

References:
  - https://en.wikipedia.org/wiki/ISO_3166-2
  - https://www.iso.org/obp/ui/#iso:code:3166:MT
"""

from iso_standards.base import EntityCollection
from iso_standards.iso3166.types import Iso3166_2 as Entity


class Iso3166_2(EntityCollection):
    __slots__ = ()

    entities = {
        "MT-01": (
            Entity("Attard", "MT-01", "LOCAL COUNCIL", "en", ""),
            Entity("Attard", "MT-01", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-02": (
            Entity("Balzan", "MT-02", "LOCAL COUNCIL", "en", ""),
            Entity("Balzan", "MT-02", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-03": (
            Entity("Birgu", "MT-03", "LOCAL COUNCIL", "en", ""),
            Entity("Birgu", "MT-03", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-04": (
            Entity("Birkirkara", "MT-04", "LOCAL COUNCIL", "en", ""),
            Entity("Birkirkara", "MT-04", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-05": (
            Entity("Birżebbuġa", "MT-05", "LOCAL COUNCIL", "en", ""),
            Entity("Birżebbuġa", "MT-05", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-06": (
            Entity("Bormla", "MT-06", "LOCAL COUNCIL", "en", ""),
            Entity("Bormla", "MT-06", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-07": (
            Entity("Dingli", "MT-07", "LOCAL COUNCIL", "en", ""),
            Entity("Dingli", "MT-07", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-08": (
            Entity("Fgura", "MT-08", "LOCAL COUNCIL", "en", ""),
            Entity("Fgura", "MT-08", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-09": (
            Entity("Floriana", "MT-09", "LOCAL COUNCIL", "en", ""),
            Entity("Floriana", "MT-09", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-10": (
            Entity("Fontana", "MT-10", "LOCAL COUNCIL", "en", ""),
            Entity("Fontana", "MT-10", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-11": (
            Entity("Gudja", "MT-11", "LOCAL COUNCIL", "en", ""),
            Entity("Gudja", "MT-11", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-12": (
            Entity("Gżira", "MT-12", "LOCAL COUNCIL", "en", ""),
            Entity("Gżira", "MT-12", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-13": (
            Entity("Għajnsielem", "MT-13", "LOCAL COUNCIL", "en", ""),
            Entity("Għajnsielem", "MT-13", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-14": (
            Entity("Għarb", "MT-14", "LOCAL COUNCIL", "en", ""),
            Entity("Għarb", "MT-14", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-15": (
            Entity("Għargħur", "MT-15", "LOCAL COUNCIL", "en", ""),
            Entity("Għargħur", "MT-15", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-16": (
            Entity("Għasri", "MT-16", "LOCAL COUNCIL", "en", ""),
            Entity("Għasri", "MT-16", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-17": (
            Entity("Għaxaq", "MT-17", "LOCAL COUNCIL", "en", ""),
            Entity("Għaxaq", "MT-17", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-18": (
            Entity("Ħamrun", "MT-18", "LOCAL COUNCIL", "en", ""),
            Entity("Ħamrun", "MT-18", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-19": (
            Entity("Iklin", "MT-19", "LOCAL COUNCIL", "en", ""),
            Entity("Iklin", "MT-19", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-20": (
            Entity("Isla", "MT-20", "LOCAL COUNCIL", "en", ""),
            Entity("Isla", "MT-20", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-21": (
            Entity("Kalkara", "MT-21", "LOCAL COUNCIL", "en", ""),
            Entity("Kalkara", "MT-21", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-22": (
            Entity("Kerċem", "MT-22", "LOCAL COUNCIL", "en", ""),
            Entity("Kerċem", "MT-22", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-23": (
            Entity("Kirkop", "MT-23", "LOCAL COUNCIL", "en", ""),
            Entity("Kirkop", "MT-23", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-24": (
            Entity("Lija", "MT-24", "LOCAL COUNCIL", "en", ""),
            Entity("Lija", "MT-24", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-25": (
            Entity("Luqa", "MT-25", "LOCAL COUNCIL", "en", ""),
            Entity("Luqa", "MT-25", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-26": (
            Entity("Marsa", "MT-26", "LOCAL COUNCIL", "en", ""),
            Entity("Marsa", "MT-26", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-27": (
            Entity("Marsaskala", "MT-27", "LOCAL COUNCIL", "en", ""),
            Entity("Marsaskala", "MT-27", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-28": (
            Entity("Marsaxlokk", "MT-28", "LOCAL COUNCIL", "en", ""),
            Entity("Marsaxlokk", "MT-28", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-29": (
            Entity("Mdina", "MT-29", "LOCAL COUNCIL", "en", ""),
            Entity("Mdina", "MT-29", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-30": (
            Entity("Mellieħa", "MT-30", "LOCAL COUNCIL", "en", ""),
            Entity("Mellieħa", "MT-30", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-31": (
            Entity("Mġarr", "MT-31", "LOCAL COUNCIL", "en", ""),
            Entity("Mġarr", "MT-31", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-32": (
            Entity("Mosta", "MT-32", "LOCAL COUNCIL", "en", ""),
            Entity("Mosta", "MT-32", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-33": (
            Entity("Mqabba", "MT-33", "LOCAL COUNCIL", "en", ""),
            Entity("Mqabba", "MT-33", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-34": (
            Entity("Msida", "MT-34", "LOCAL COUNCIL", "en", ""),
            Entity("Msida", "MT-34", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-35": (
            Entity("Mtarfa", "MT-35", "LOCAL COUNCIL", "en", ""),
            Entity("Mtarfa", "MT-35", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-36": (
            Entity("Munxar", "MT-36", "LOCAL COUNCIL", "en", ""),
            Entity("Munxar", "MT-36", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-37": (
            Entity("Nadur", "MT-37", "LOCAL COUNCIL", "en", ""),
            Entity("Nadur", "MT-37", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-38": (
            Entity("Naxxar", "MT-38", "LOCAL COUNCIL", "en", ""),
            Entity("Naxxar", "MT-38", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-39": (
            Entity("Paola", "MT-39", "LOCAL COUNCIL", "en", ""),
            Entity("Paola", "MT-39", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-40": (
            Entity("Pembroke", "MT-40", "LOCAL COUNCIL", "en", ""),
            Entity("Pembroke", "MT-40", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-41": (
            Entity("Pietà", "MT-41", "LOCAL COUNCIL", "en", ""),
            Entity("Pietà", "MT-41", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-42": (
            Entity("Qala", "MT-42", "LOCAL COUNCIL", "en", ""),
            Entity("Qala", "MT-42", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-43": (
            Entity("Qormi", "MT-43", "LOCAL COUNCIL", "en", ""),
            Entity("Qormi", "MT-43", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-44": (
            Entity("Qrendi", "MT-44", "LOCAL COUNCIL", "en", ""),
            Entity("Qrendi", "MT-44", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-45": (
            Entity("Rabat Gozo", "MT-45", "LOCAL COUNCIL", "en", ""),
            Entity("Rabat Għawdex", "MT-45", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-46": (
            Entity("Rabat Malta", "MT-46", "LOCAL COUNCIL", "en", ""),
            Entity("Rabat Malta", "MT-46", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-47": (
            Entity("Safi", "MT-47", "LOCAL COUNCIL", "en", ""),
            Entity("Safi", "MT-47", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-48": (
            Entity("Saint Julian's", "MT-48", "LOCAL COUNCIL", "en", ""),
            Entity("San Ġiljan", "MT-48", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-49": (
            Entity("Saint John", "MT-49", "LOCAL COUNCIL", "en", ""),
            Entity("San Ġwann", "MT-49", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-50": (
            Entity("Saint Lawrence", "MT-50", "LOCAL COUNCIL", "en", ""),
            Entity("San Lawrenz", "MT-50", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-51": (
            Entity("Saint Paul's Bay", "MT-51", "LOCAL COUNCIL", "en", ""),
            Entity("San Pawl il-Baħar", "MT-51", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-52": (
            Entity("Sannat", "MT-52", "LOCAL COUNCIL", "en", ""),
            Entity("Sannat", "MT-52", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-53": (
            Entity("Saint Lucia's", "MT-53", "LOCAL COUNCIL", "en", ""),
            Entity("Santa Luċija", "MT-53", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-54": (
            Entity("Santa Venera", "MT-54", "LOCAL COUNCIL", "en", ""),
            Entity("Santa Venera", "MT-54", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-55": (
            Entity("Siġġiewi", "MT-55", "LOCAL COUNCIL", "en", ""),
            Entity("Siġġiewi", "MT-55", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-56": (
            Entity("Sliema", "MT-56", "LOCAL COUNCIL", "en", ""),
            Entity("Sliema", "MT-56", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-57": (
            Entity("Swieqi", "MT-57", "LOCAL COUNCIL", "en", ""),
            Entity("Swieqi", "MT-57", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-58": (
            Entity("Ta' Xbiex", "MT-58", "LOCAL COUNCIL", "en", ""),
            Entity("Ta' Xbiex", "MT-58", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-59": (
            Entity("Tarxien", "MT-59", "LOCAL COUNCIL", "en", ""),
            Entity("Tarxien", "MT-59", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-60": (
            Entity("Valletta", "MT-60", "LOCAL COUNCIL", "en", ""),
            Entity("Valletta", "MT-60", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-61": (
            Entity("Xagħra", "MT-61", "LOCAL COUNCIL", "en", ""),
            Entity("Xagħra", "MT-61", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-62": (
            Entity("Xewkija", "MT-62", "LOCAL COUNCIL", "en", ""),
            Entity("Xewkija", "MT-62", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-63": (
            Entity("Xgħajra", "MT-63", "LOCAL COUNCIL", "en", ""),
            Entity("Xgħajra", "MT-63", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-64": (
            Entity("Żabbar", "MT-64", "LOCAL COUNCIL", "en", ""),
            Entity("Żabbar", "MT-64", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-65": (
            Entity("Żebbuġ Gozo", "MT-65", "LOCAL COUNCIL", "en", ""),
            Entity("Żebbuġ Għawdex", "MT-65", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-66": (
            Entity("Żebbuġ Malta", "MT-66", "LOCAL COUNCIL", "en", ""),
            Entity("Żebbuġ Malta", "MT-66", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-67": (
            Entity("Żejtun", "MT-67", "LOCAL COUNCIL", "en", ""),
            Entity("Żejtun", "MT-67", "LOCAL COUNCIL", "mt", ""),
        ),
        "MT-68": (
            Entity("Żurrieq", "MT-68", "LOCAL COUNCIL", "en", ""),
            Entity("Żurrieq", "MT-68", "LOCAL COUNCIL", "mt", ""),
        ),
    }
