"""ISO 3166-2 TR standard representation.

References:
  - https://en.wikipedia.org/wiki/ISO_3166-2
  - https://www.iso.org/obp/ui/#iso:code:3166:TR
"""

from iso_standards.base import EntityCollection
from iso_standards.iso3166.types import Iso3166_2 as Entity


class Iso3166_2(EntityCollection):
    __slots__ = ()

    entities = {
        "TR-01": (Entity("Adana", "TR-01", "PROVINCE", "tr", ""),),
        "TR-02": (Entity("Adıyaman", "TR-02", "PROVINCE", "tr", ""),),
        "TR-03": (Entity("Afyonkarahisar", "TR-03", "PROVINCE", "tr", ""),),
        "TR-04": (Entity("Ağrı", "TR-04", "PROVINCE", "tr", ""),),
        "TR-05": (Entity("Amasya", "TR-05", "PROVINCE", "tr", ""),),
        "TR-06": (Entity("Ankara", "TR-06", "PROVINCE", "tr", ""),),
        "TR-07": (Entity("Antalya", "TR-07", "PROVINCE", "tr", ""),),
        "TR-08": (Entity("Artvin", "TR-08", "PROVINCE", "tr", ""),),
        "TR-09": (Entity("Aydın", "TR-09", "PROVINCE", "tr", ""),),
        "TR-10": (Entity("Balıkesir", "TR-10", "PROVINCE", "tr", ""),),
        "TR-11": (Entity("Bilecik", "TR-11", "PROVINCE", "tr", ""),),
        "TR-12": (Entity("Bingöl", "TR-12", "PROVINCE", "tr", ""),),
        "TR-13": (Entity("Bitlis", "TR-13", "PROVINCE", "tr", ""),),
        "TR-14": (Entity("Bolu", "TR-14", "PROVINCE", "tr", ""),),
        "TR-15": (Entity("Burdur", "TR-15", "PROVINCE", "tr", ""),),
        "TR-16": (Entity("Bursa", "TR-16", "PROVINCE", "tr", ""),),
        "TR-17": (Entity("Çanakkale", "TR-17", "PROVINCE", "tr", ""),),
        "TR-18": (Entity("Çankırı", "TR-18", "PROVINCE", "tr", ""),),
        "TR-19": (Entity("Çorum", "TR-19", "PROVINCE", "tr", ""),),
        "TR-20": (Entity("Denizli", "TR-20", "PROVINCE", "tr", ""),),
        "TR-21": (Entity("Diyarbakır", "TR-21", "PROVINCE", "tr", ""),),
        "TR-22": (Entity("Edirne", "TR-22", "PROVINCE", "tr", ""),),
        "TR-23": (Entity("Elazığ", "TR-23", "PROVINCE", "tr", ""),),
        "TR-24": (Entity("Erzincan", "TR-24", "PROVINCE", "tr", ""),),
        "TR-25": (Entity("Erzurum", "TR-25", "PROVINCE", "tr", ""),),
        "TR-26": (Entity("Eskişehir", "TR-26", "PROVINCE", "tr", ""),),
        "TR-27": (Entity("Gaziantep", "TR-27", "PROVINCE", "tr", ""),),
        "TR-28": (Entity("Giresun", "TR-28", "PROVINCE", "tr", ""),),
        "TR-29": (Entity("Gümüşhane", "TR-29", "PROVINCE", "tr", ""),),
        "TR-30": (Entity("Hakkâri", "TR-30", "PROVINCE", "tr", ""),),
        "TR-31": (Entity("Hatay", "TR-31", "PROVINCE", "tr", ""),),
        "TR-32": (Entity("Isparta", "TR-32", "PROVINCE", "tr", ""),),
        "TR-33": (Entity("Mersin", "TR-33", "PROVINCE", "tr", ""),),
        "TR-34": (Entity("İstanbul", "TR-34", "PROVINCE", "tr", ""),),
        "TR-35": (Entity("İzmir", "TR-35", "PROVINCE", "tr", ""),),
        "TR-36": (Entity("Kars", "TR-36", "PROVINCE", "tr", ""),),
        "TR-37": (Entity("Kastamonu", "TR-37", "PROVINCE", "tr", ""),),
        "TR-38": (Entity("Kayseri", "TR-38", "PROVINCE", "tr", ""),),
        "TR-39": (Entity("Kırklareli", "TR-39", "PROVINCE", "tr", ""),),
        "TR-40": (Entity("Kırşehir", "TR-40", "PROVINCE", "tr", ""),),
        "TR-41": (Entity("Kocaeli", "TR-41", "PROVINCE", "tr", ""),),
        "TR-42": (Entity("Konya", "TR-42", "PROVINCE", "tr", ""),),
        "TR-43": (Entity("Kütahya", "TR-43", "PROVINCE", "tr", ""),),
        "TR-44": (Entity("Malatya", "TR-44", "PROVINCE", "tr", ""),),
        "TR-45": (Entity("Manisa", "TR-45", "PROVINCE", "tr", ""),),
        "TR-46": (Entity("Kahramanmaraş", "TR-46", "PROVINCE", "tr", ""),),
        "TR-47": (Entity("Mardin", "TR-47", "PROVINCE", "tr", ""),),
        "TR-48": (Entity("Muğla", "TR-48", "PROVINCE", "tr", ""),),
        "TR-49": (Entity("Muş", "TR-49", "PROVINCE", "tr", ""),),
        "TR-50": (Entity("Nevşehir", "TR-50", "PROVINCE", "tr", ""),),
        "TR-51": (Entity("Niğde", "TR-51", "PROVINCE", "tr", ""),),
        "TR-52": (Entity("Ordu", "TR-52", "PROVINCE", "tr", ""),),
        "TR-53": (Entity("Rize", "TR-53", "PROVINCE", "tr", ""),),
        "TR-54": (Entity("Sakarya", "TR-54", "PROVINCE", "tr", ""),),
        "TR-55": (Entity("Samsun", "TR-55", "PROVINCE", "tr", ""),),
        "TR-56": (Entity("Siirt", "TR-56", "PROVINCE", "tr", ""),),
        "TR-57": (Entity("Sinop", "TR-57", "PROVINCE", "tr", ""),),
        "TR-58": (Entity("Sivas", "TR-58", "PROVINCE", "tr", ""),),
        "TR-59": (Entity("Tekirdağ", "TR-59", "PROVINCE", "tr", ""),),
        "TR-60": (Entity("Tokat", "TR-60", "PROVINCE", "tr", ""),),
        "TR-61": (Entity("Trabzon", "TR-61", "PROVINCE", "tr", ""),),
        "TR-62": (Entity("Tunceli", "TR-62", "PROVINCE", "tr", ""),),
        "TR-63": (Entity("Şanlıurfa", "TR-63", "PROVINCE", "tr", ""),),
        "TR-64": (Entity("Uşak", "TR-64", "PROVINCE", "tr", ""),),
        "TR-65": (Entity("Van", "TR-65", "PROVINCE", "tr", ""),),
        "TR-66": (Entity("Yozgat", "TR-66", "PROVINCE", "tr", ""),),
        "TR-67": (Entity("Zonguldak", "TR-67", "PROVINCE", "tr", ""),),
        "TR-68": (Entity("Aksaray", "TR-68", "PROVINCE", "tr", ""),),
        "TR-69": (Entity("Bayburt", "TR-69", "PROVINCE", "tr", ""),),
        "TR-70": (Entity("Karaman", "TR-70", "PROVINCE", "tr", ""),),
        "TR-71": (Entity("Kırıkkale", "TR-71", "PROVINCE", "tr", ""),),
        "TR-72": (Entity("Batman", "TR-72", "PROVINCE", "tr", ""),),
        "TR-73": (Entity("Şırnak", "TR-73", "PROVINCE", "tr", ""),),
        "TR-74": (Entity("Bartın", "TR-74", "PROVINCE", "tr", ""),),
        "TR-75": (Entity("Ardahan", "TR-75", "PROVINCE", "tr", ""),),
        "TR-76": (Entity("Iğdır", "TR-76", "PROVINCE", "tr", ""),),
        "TR-77": (Entity("Yalova", "TR-77", "PROVINCE", "tr", ""),),
        "TR-78": (Entity("Karabük", "TR-78", "PROVINCE", "tr", ""),),
        "TR-79": (Entity("Kilis", "TR-79", "PROVINCE", "tr", ""),),
        "TR-80": (Entity("Osmaniye", "TR-80", "PROVINCE", "tr", ""),),
        "TR-81": (Entity("Düzce", "TR-81", "PROVINCE", "tr", ""),),
    }
